@@ -1,7 +1,7 @@
 #
 # Session - Itcl object for web session management for Rivet
 #
-# $Id: session-class.tcl 1373643 2012-08-15 21:45:39Z mxmanghi $
+# $Id: session-class.tcl 1432441 2013-01-12 14:58:58Z mxmanghi $
 #
 
 # Copyright 2004 The Apache Software Foundation
@@ -316,8 +316,8 @@ package require Itcl
 	set kf [list session_id package_ key_]
 
 	if {![$dioObject store a -table $sessionCacheTable -keyfield $kf]} {
-	    puts "Failed to store $sessionCacheTable '$kf'"
-	    parray a
+	    debug "Failed to store $sessionCacheTable '$kf'"
+	    #parray a
 	    error [$dioObject errorinfo]
 	}
     }
