@@ -15,7 +15,7 @@
    limitations under the License.
 */
 
-/* $Id: mod_rivet.c 1374729 2012-08-19 11:09:10Z mxmanghi $ */
+/* $Id: mod_rivet.c 1492454 2013-06-12 22:20:46Z mxmanghi $ */
 
 /* Rivet config */
 #ifdef HAVE_CONFIG_H
@@ -370,7 +370,7 @@ Rivet_ExecuteAndCheck(Tcl_Interp *interp, Tcl_Obj *outbuf, request_rec *req)
             ap_assert (Tcl_ListObjIndex (interp, errorCodeListObj, 1, &errorCodeElementObj) == TCL_OK);
 
             errorCodeSubString = Tcl_GetString (errorCodeElementObj);
-            if (strcmp (errorCodeSubString, "ABORTPAGE") == 0) 
+            if (strcmp (errorCodeSubString, ABORTPAGE_CODE) == 0) 
             {
                 if (conf->rivet_abort_script) 
                 {
@@ -924,7 +924,7 @@ Rivet_PerInterpInit(server_rec *s, rivet_server_conf *rsc, apr_pool_t *p)
     /* Eval Rivet's init.tcl file to load in the Tcl-level commands. */
 
     /* We put in front the auto_path list the path to the directory where
-     * init.tcl is located (provides package RivetTcl)
+     * init.tcl is located (provides package Rivet, previously RivetTcl)
      */
 
     auto_path = Tcl_GetVar2Ex(interp,"auto_path",NULL,TCL_GLOBAL_ONLY);
@@ -947,21 +947,35 @@ Rivet_PerInterpInit(server_rec *s, rivet_server_conf *rsc, apr_pool_t *p)
     Rivet_InitServerVariables(interp, p );
 //  Rivet_PropagateServerConfArray( interp, rsc );
 
-    /* Eval Rivet's init.tcl file to load in the Tcl-level commands. */
 
-    /* Watch out! Calling Tcl_PkgRequire with a version number binds this module to
-     * the 'package provide' statement in rivet/init.tcl 
+    /* Loading into the interpreter the commands provided by librivet.so */
+    /* Tcl Bug #3216070 has been solved with 8.5.10 and commands shipped with
+     * Rivetlib can be mapped at this stage
      */
 
-    /*  If rivet was configured to export the ::rivet namespace commands we have to
-     *  set the array variable ::rivet::module_conf(export_namespace_commands) before calling init.tcl
+    if (Tcl_PkgRequire(interp, RIVETLIB_TCL_PACKAGE, RIVET_VERSION, 1) == NULL)
+    {
+        ap_log_error(APLOG_MARK, APLOG_ERR, APR_EGENERAL, s,
+                     MODNAME ": Error loading rivetlib package: %s",
+		     Tcl_GetStringResult(interp) );
+        exit(1);
+    }
+
+    /*  If rivet is configured to export the ::rivet namespace commands we set the
+     *  array variable ::rivet::module_conf(export_namespace_commands) before calling init.tcl
      *  This array will be unset after commands are exported.
      */
 
     Tcl_SetVar2Ex(interp,"module_conf","export_namespace_commands",Tcl_NewIntObj(RIVET_NAMESPACE_EXPORT),0);
     Tcl_SetVar2Ex(interp,"module_conf","import_rivet_commands",Tcl_NewIntObj(RIVET_NAMESPACE_IMPORT),0);
 
-    if (Tcl_PkgRequire(interp, "RivetTcl", "2.1", 1) == NULL)
+    /* Eval Rivet's init.tcl file to load in the Tcl-level commands. */
+
+    /* Watch out! Calling Tcl_PkgRequire with a version number binds this module to
+     * the Rivet package revision number in rivet/init.tcl
+     */
+
+    if (Tcl_PkgRequire(interp, "Rivet", "2.1", 1) == NULL)
     {
         ap_log_error (APLOG_MARK, APLOG_ERR, APR_EGENERAL, s,
                       MODNAME ": init.tcl must be installed correctly for Apache Rivet to function: %s (%s)",
@@ -969,19 +983,6 @@ Rivet_PerInterpInit(server_rec *s, rivet_server_conf *rsc, apr_pool_t *p)
         exit(1);
     }
 
-    /* Loading into the interpreter the commands provided by librivet.so */
-
-    /* Tcl Bug #3216070 has been solved with 8.5.10 and commands shipped with
-     * Rivetlib can be mapped at this stage
-     */
-
-    if (Tcl_PkgRequire(interp, RIVETLIB_TCL_PACKAGE, "1.2", 1) == NULL)
-    {
-        ap_log_error(APLOG_MARK, APLOG_ERR, APR_EGENERAL, s,
-                     MODNAME ": Error loading rivetlib package: %s",
-		     Tcl_GetStringResult(interp) );
-        exit(1);
-    } 
     /* */
 
     /* Set the output buffer size to the largest allowed value, so that we 
@@ -1251,7 +1252,7 @@ Rivet_InitHandler(apr_pool_t *pPool, apr_pool_t *pLog, apr_pool_t *pTemp,
     rivet_panic_server_rec = s;
 
 #if RIVET_DISPLAY_VERSION
-    ap_add_version_component(pPool, RIVET_PACKAGE_NAME"/"RIVET_PACKAGE_VERSION);
+    ap_add_version_component(pPool, RIVET_PACKAGE_NAME"/"RIVET_VERSION);
 #else
     ap_add_version_component(pPool, RIVET_PACKAGE_NAME);
 #endif
@@ -1549,9 +1550,15 @@ Rivet_ChildHandlers(server_rec *s, int init)
 static apr_status_t
 Rivet_ChildExit(void *data)
 {
-    server_rec *s = (server_rec*) data;
+    server_rec  *s = (server_rec*) data;
+
+    ap_log_error(APLOG_MARK, APLOG_DEBUG, APR_EGENERAL, s, MODNAME ": Running ChildExit handler");
     Rivet_ChildHandlers(s, 0);
-    Tcl_Finalize();
+
+/* Tcl_Finalize remove to meet requirement to coexist with mod_websh (Bug #54162) */
+
+    //Tcl_Finalize();
+
     return OK;
 }
 
@@ -1561,8 +1568,10 @@ Rivet_ChildExit(void *data)
  *
  * Arguments:
  *  server_rec* s: pointer to a server_rec structure
+ *
  * Results:
  *  pointer to a Tcl_Interp structure
+ *
  * Side Effects:
  *
  *-----------------------------------------------------------------------------
@@ -1823,7 +1832,9 @@ Rivet_SendContent(request_rec *r)
 
     r->allowed |= (1 << M_GET);
     r->allowed |= (1 << M_POST);
-    if (r->method_number != M_GET && r->method_number != M_POST) {
+    r->allowed |= (1 << M_PUT);
+    r->allowed |= (1 << M_DELETE);
+    if (r->method_number != M_GET && r->method_number != M_POST && r->method_number != M_PUT && r->method_number != M_DELETE) {
         retval = DECLINED;
         goto sendcleanup;
     }
@@ -1843,9 +1854,6 @@ Rivet_SendContent(request_rec *r)
         goto sendcleanup;
     }
 
-//    apr_cpystrn(error, DEFAULT_ERROR_MSG, sizeof(error));
-//    apr_cpystrn(timefmt, DEFAULT_TIME_FORMAT, sizeof(timefmt));
-
     /* 
      * This one is the big catch when it comes to moving towards
      * Apache 2.0, or one of them, at least.
