@@ -15,7 +15,7 @@
    limitations under the License.
 */
 
-/* $Id: mod_rivet.h 1335266 2012-05-07 21:20:11Z mxmanghi $ */
+/* $Id: mod_rivet.h 1444856 2013-02-11 16:39:17Z mxmanghi $ */
 
 #ifndef MOD_RIVET_H
 #define MOD_RIVET_H 1
@@ -140,5 +140,10 @@ Tcl_Obj* Rivet_ReadConfParameter (  Tcl_Interp*         interp,
 
 Tcl_Obj* Rivet_CurrentConfDict (    Tcl_Interp*           interp,
                                     rivet_server_conf*    rivet_conf);
+
+/* error code set by command 'abort_page' */
+
+#define ABORTPAGE_CODE "ABORTPAGE"
+
 #endif /* MOD_RIVET_H */
 
