@@ -17,7 +17,7 @@
    limitations under the License.
 */
 
-/* $Id: rivetCore.c 1335266 2012-05-07 21:20:11Z mxmanghi $ */
+/* $Id: rivetCore.c 1479588 2013-05-06 14:43:03Z mxmanghi $ */
 
 /* Rivet config */
 #ifdef HAVE_CONFIG_H
@@ -351,7 +351,8 @@ TCL_CMD_HEADER( Rivet_Headers )
             return TCL_ERROR;
         }
         TclWeb_SetHeaderType(Tcl_GetString(objv[2]), globals->req);
-    } else if (!strcmp("numeric", opt)) /* ### numeric ### */
+    }
+    else if (!strcmp("numeric", opt)) /* ### numeric ### */
     {
         int st = 200;
 
@@ -365,7 +366,15 @@ TCL_CMD_HEADER( Rivet_Headers )
         } else {
             return TCL_ERROR;
         }
+
     } else {
+
+        Tcl_Obj* result = Tcl_NewStringObj("unrecognized subcommand: ",-1);
+        Tcl_IncrRefCount(result);
+        Tcl_AppendStringsToObj(result,opt,NULL);
+
+        Tcl_SetObjResult(interp, result);
+        Tcl_DecrRefCount(result);
         return TCL_ERROR;
     }
     return TCL_OK;
@@ -1130,7 +1139,7 @@ TCL_CMD_HEADER( Rivet_AbortPageCmd )
     globals->page_aborting = 1;
 
     Tcl_AddErrorInfo (interp, errorMessage);
-    Tcl_SetErrorCode (interp, "RIVET", "ABORTPAGE", errorMessage, (char *)NULL);
+    Tcl_SetErrorCode (interp, "RIVET", ABORTPAGE_CODE, errorMessage, (char *)NULL);
     return TCL_ERROR;
 }
 
@@ -1447,7 +1456,7 @@ TestpanicCmd(dummy, interp, argc, argv)
      */
 
     argString = Tcl_Merge(argc-1, argv+1);
-    panic(argString);
+    panic("%s",argString);
     ckfree((char *)argString);
 
     return TCL_OK;
